"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.computeOffsets = computeOffsets;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function computeOffsets(placement, popperRect, referenceRect) {
  var _ref = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {},
      _ref$preventOverflow = _ref.preventOverflow,
      preventOverflow = _ref$preventOverflow === void 0 ? false : _ref$preventOverflow,
      _ref$sameWidth = _ref.sameWidth,
      sameWidth = _ref$sameWidth === void 0 ? false : _ref$sameWidth;

  var offsets = {
    x: 0,
    y: 0
  };
  var clipping = {};

  if (!popperRect || !referenceRect) {
    return {
      offsets: offsets,
      clipping: clipping
    };
  }

  var commonX = sameWidth ? referenceRect.left : referenceRect.left + referenceRect.width / 2 - popperRect.width / 2;

  switch (placement) {
    case 'top':
      offsets = {
        x: commonX,
        y: referenceRect.top - popperRect.height
      };
      break;

    case 'bottom':
      offsets = {
        x: commonX,
        y: referenceRect.bottom
      };
      break;
  }

  if (!sameWidth && preventOverflow) {
    clipping = getClipping(offsets, popperRect);

    if (clipping.right && !clipping.left) {
      offsets.x += clipping.right;
    }

    if (!clipping.right && clipping.left) {
      offsets.x = 0;
    }
  }

  return {
    offsets: offsets,
    clipping: clipping
  };
}

function getClipping(offsets, popperRect) {
  var viewportWidth = document.documentElement.clientWidth;
  var elementWidth = offsets.x + popperRect.width;
  var clipping = {};

  if (elementWidth > viewportWidth) {
    clipping = {
      right: viewportWidth - elementWidth
    };
  }

  if (offsets.x < 0) {
    clipping = _objectSpread(_objectSpread({}, clipping), {}, {
      left: -offsets.x
    });
  }

  return clipping;
}