function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useState, useCallback, useEffect, useRef } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { Portal } from '../Portal';
import { Heading } from '../Heading';
import { Icon } from '../Icon';
import { useTransition } from '../../utilities/transition';
import styles from './Modal.css';
var IFRAME_LOADING_HEIGHT = 200;
var DEFAULT_IFRAME_CONTENT_HEIGHT = 400;

function isIFrameProps(props) {
  return props.src !== undefined;
}

export function Modal(_ref) {
  var _ref$open = _ref.open,
      openProp = _ref$open === void 0 ? false : _ref$open,
      title = _ref.title,
      height = _ref.height,
      onClose = _ref.onClose,
      props = _objectWithoutProperties(_ref, ["open", "title", "height", "onClose"]);

  var iFrameTitle = 'body markup';

  var _useState = useState(openProp),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var _useState3 = useState(IFRAME_LOADING_HEIGHT),
      _useState4 = _slicedToArray(_useState3, 2),
      iframeHeight = _useState4[0],
      setIframeHeight = _useState4[1];

  var titleBarRef = useRef(null);
  var transition = useTransition(open, {
    enter: 'fast'
  });
  var transitionClassName = styles[variationName('transition', transition)];
  var closeModal = useCallback(function () {
    setOpen(false);
    if (onClose) onClose();
  }, [onClose]);
  var handleKeyDown = useCallback(function (event) {
    return event.key === 'Escape' && closeModal();
  }, [closeModal]);
  useEffect(function () {
    if (openProp) {
      setOpen(true);
    } else {
      closeModal();
    }
  }, [openProp, closeModal]);
  useEffect(function () {
    document.addEventListener('keydown', handleKeyDown, false);
    return function () {
      document.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [handleKeyDown]);
  var handleIFrameLoad = useCallback(function (evt) {
    var iframe = evt.target;

    if (iframe && iframe.contentWindow) {
      try {
        setIframeHeight(iframe.contentWindow.document.body.scrollHeight);
      } catch (_unused) {
        setIframeHeight(DEFAULT_IFRAME_CONTENT_HEIGHT);
      }
    }
  }, []);
  if (!open) return null; // TODO handle focus

  var contentHeight;

  if (height) {
    if (title) {
      var _titleBarRef$current$, _titleBarRef$current;

      contentHeight = "".concat(height - ((_titleBarRef$current$ = (_titleBarRef$current = titleBarRef.current) === null || _titleBarRef$current === void 0 ? void 0 : _titleBarRef$current.clientHeight) !== null && _titleBarRef$current$ !== void 0 ? _titleBarRef$current$ : 64), "px");
    }

    contentHeight = "".concat(height, "px");
  } else if (isIFrameProps(props)) {
    contentHeight = "".concat(iframeHeight, "px");
  } else {
    contentHeight = 'auto';
  }

  return /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement("div", {
    className: styles.Wrapper
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.Backdrop, transitionClassName)
  }), /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.Content, transitionClassName)
  }, title && /*#__PURE__*/React.createElement("header", {
    className: styles.Header,
    ref: titleBarRef
  }, /*#__PURE__*/React.createElement(Heading, {
    level: 1
  }, title), /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: styles.Button,
    onClick: function onClick() {
      return closeModal();
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    source: "close",
    size: "large"
  }))), isIFrameProps(props) ?
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
  React.createElement("iframe", {
    src: props.src,
    name: props.iFrameName,
    onLoad: handleIFrameLoad,
    title: iFrameTitle,
    className: styles.IFrame,
    style: {
      // stylelint-disable-next-line value-keyword-case
      height: contentHeight
    }
  }) : /*#__PURE__*/React.createElement("div", {
    className: styles.Body,
    style: {
      // stylelint-disable-next-line value-keyword-case
      height: contentHeight
    }
  }, props.children))));
}