function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import { TextBlock } from '../../../TextBlock';
import { Stepper } from '../../Stepper';
import { VisuallyHidden } from '../../../VisuallyHidden';
import { StepperStep, StepperStepIcon, StepperStepLabel, StepperStepConnector } from './StepperStep';

var defaultProps = function defaultProps(id) {
  return {
    id: "step".concat(id),
    icon: 'checkmark',
    label: "Step ".concat(id),
    state: "State ".concat(id)
  };
};

describe('<StepperStep />', function () {
  it('renders a <StepperStepConnector /> except for first StepperStep', function () {
    var stepper = mount( /*#__PURE__*/React.createElement(Stepper, {
      activeStep: "step3"
    }, /*#__PURE__*/React.createElement(StepperStep, defaultProps(1)), /*#__PURE__*/React.createElement(StepperStep, defaultProps(2)), /*#__PURE__*/React.createElement(StepperStep, defaultProps(3))));

    var _stepper$findAll = stepper.findAll(StepperStep),
        _stepper$findAll2 = _slicedToArray(_stepper$findAll, 3),
        firstStepperStep = _stepper$findAll2[0],
        secondStepperStep = _stepper$findAll2[1],
        finalStepperStep = _stepper$findAll2[2];

    expect(firstStepperStep).not.toContainReactComponent(StepperStepConnector);
    expect(secondStepperStep).toContainReactComponent(StepperStepConnector, {
      active: false,
      completed: true
    });
    expect(finalStepperStep).toContainReactComponent(StepperStepConnector, {
      active: true,
      completed: false
    });
  });
  it('renders <StepperStepIcon />', function () {
    var stepper = mount( /*#__PURE__*/React.createElement(Stepper, {
      activeStep: "step2"
    }, /*#__PURE__*/React.createElement(StepperStep, defaultProps(1)), /*#__PURE__*/React.createElement(StepperStep, defaultProps(2)), /*#__PURE__*/React.createElement(StepperStep, Object.assign({}, defaultProps(3), {
      iconColor: "critical"
    }))));

    var _stepper$findAll3 = stepper.findAll(StepperStep),
        _stepper$findAll4 = _slicedToArray(_stepper$findAll3, 3),
        firstStepperStep = _stepper$findAll4[0],
        secondStepperStep = _stepper$findAll4[1],
        finalStepperStep = _stepper$findAll4[2];

    expect(firstStepperStep).toContainReactComponent(StepperStepIcon, {
      active: false,
      completed: true,
      source: 'checkmark'
    });
    expect(secondStepperStep).toContainReactComponent(StepperStepIcon, {
      active: true,
      completed: false,
      source: 'checkmark'
    });
    expect(finalStepperStep).toContainReactComponent(StepperStepIcon, {
      active: false,
      completed: false,
      source: 'checkmark',
      color: 'critical'
    });
  });
  it('renders <StepperStepLabel /> with state', function () {
    var stepper = mount( /*#__PURE__*/React.createElement(Stepper, null, /*#__PURE__*/React.createElement(StepperStep, defaultProps(1)), /*#__PURE__*/React.createElement(StepperStep, Object.assign({}, defaultProps(2), {
      stateHidden: false
    }))));

    var _stepper$findAll5 = stepper.findAll(StepperStep),
        _stepper$findAll6 = _slicedToArray(_stepper$findAll5, 2),
        firstStepperStep = _stepper$findAll6[0],
        finalStepperStep = _stepper$findAll6[1];

    expect(firstStepperStep).toContainReactComponent(StepperStepLabel, {
      state: 'State 1'
    });
    expect(finalStepperStep).toContainReactComponent(StepperStepLabel, {
      state: 'State 2'
    });
    expect(firstStepperStep).toContainReactComponent(VisuallyHidden);
    expect(firstStepperStep).toContainReactComponentTimes(TextBlock, 1);
    expect(finalStepperStep).not.toContainReactComponent(VisuallyHidden);
    expect(finalStepperStep).toContainReactComponentTimes(TextBlock, 2);
    expect(firstStepperStep.find(VisuallyHidden)).toContainReactText('State 1');
    expect(finalStepperStep.find(TextBlock)).toContainReactText('State 2');
  });
  it('renders <StepperStepLabel /> with label or description', function () {
    var stepper = mount( /*#__PURE__*/React.createElement(Stepper, {
      activeStep: "step2"
    }, /*#__PURE__*/React.createElement(StepperStep, Object.assign({}, defaultProps(1), {
      description: "Description 1"
    })), /*#__PURE__*/React.createElement(StepperStep, Object.assign({}, defaultProps(2), {
      description: "Description 2"
    })), /*#__PURE__*/React.createElement(StepperStep, defaultProps(3))));

    var _stepper$findAll7 = stepper.findAll(StepperStep),
        _stepper$findAll8 = _slicedToArray(_stepper$findAll7, 3),
        firstStepperStep = _stepper$findAll8[0],
        secondStepperStep = _stepper$findAll8[1],
        finalStepperStep = _stepper$findAll8[2];

    expect(firstStepperStep).toContainReactComponent(StepperStepLabel, {
      label: 'Step 1',
      description: 'Description 1'
    });
    expect(secondStepperStep).toContainReactComponent(StepperStepLabel, {
      label: 'Step 2',
      description: 'Description 2'
    });
    expect(finalStepperStep).toContainReactComponent(StepperStepLabel, {
      label: 'Step 3'
    });
    expect(firstStepperStep.find(TextBlock)).toContainReactText('Step 1');
    expect(secondStepperStep.find(TextBlock)).toContainReactText('Step 2');
    expect(finalStepperStep.find(TextBlock)).toContainReactText('Step 3');
    expect(firstStepperStep).toContainReactComponentTimes(TextBlock, 2);
    expect(secondStepperStep).toContainReactComponentTimes(TextBlock, 2);
    expect(finalStepperStep).toContainReactComponentTimes(TextBlock, 1);
  });
  it('renders a <li> with a aria-current attribute', function () {
    var stepper = mount( /*#__PURE__*/React.createElement(Stepper, {
      activeStep: "step2"
    }, /*#__PURE__*/React.createElement(StepperStep, defaultProps(1)), /*#__PURE__*/React.createElement(StepperStep, defaultProps(2)), /*#__PURE__*/React.createElement(StepperStep, defaultProps(3))));

    var _stepper$findAll9 = stepper.findAll(StepperStep),
        _stepper$findAll10 = _slicedToArray(_stepper$findAll9, 3),
        firstStepperStep = _stepper$findAll10[0],
        secondStepperStep = _stepper$findAll10[1],
        finalStepperStep = _stepper$findAll10[2];

    expect(firstStepperStep).toContainReactComponent('li', {
      'aria-current': false
    });
    expect(secondStepperStep).toContainReactComponent('li', {
      'aria-current': true
    });
    expect(finalStepperStep).toContainReactComponent('li', {
      'aria-current': false
    });
  });
});