function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useRef, useState } from 'react';
import { classNames, variationName } from '@shopify/css-utilities';
import { createIdCreator, useId } from '../../utilities/id';
import { useTransition } from '../../utilities/transition';
import { Popper, usePopper } from '../Popper';
import styles from './Tooltip.css';
export var RETURN_KEY_CODE = 13;
export var ESCAPE_KEY_CODE = 27;
export var SPACE_KEY_CODE = 32;
var createId = createIdCreator('Tooltip');
export function Tooltip(_ref) {
  var content = _ref.content,
      children = _ref.children;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      active = _useState2[0],
      setActive = _useState2[1];

  var buttonRef = useRef(null);
  var transition = useTransition(active, {
    exit: 'slow'
  });

  function handleKeyDown(event) {
    switch (event.keyCode) {
      case RETURN_KEY_CODE:
      case SPACE_KEY_CODE:
        event.preventDefault();
        setActive(!active);
        break;

      case ESCAPE_KEY_CODE:
        event.preventDefault();
        setActive(false);
        break;
    }
  }

  function handleClick() {
    setActive(!active);
  }

  var className = classNames(styles.Tooltip, styles[variationName('transition', transition)]);
  var id = useId(undefined, createId);
  var controlId = active ? id : undefined;
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Wrapper
  }, /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: styles.Button,
    "aria-pressed": active,
    "aria-controls": controlId,
    "aria-describedby": controlId,
    onFocus: function onFocus() {
      setActive(true);
    },
    onBlur: function onBlur() {
      setActive(false);
    },
    onMouseEnter: function onMouseEnter() {
      setActive(true);
    },
    onMouseLeave: function onMouseLeave() {
      setActive(false);
    },
    onClick: handleClick,
    onKeyDown: handleKeyDown,
    ref: buttonRef
  }, children), transition !== 'exited' && /*#__PURE__*/React.createElement(Popper, {
    activator: buttonRef.current,
    preventOverflow: true
  }, /*#__PURE__*/React.createElement("p", {
    id: controlId,
    role: "tooltip",
    onMouseEnter: function onMouseEnter() {
      setActive(true);
    },
    onMouseLeave: function onMouseLeave() {
      setActive(false);
    },
    className: className
  }, content, /*#__PURE__*/React.createElement(Arrow, null))));
}
export function Arrow() {
  var _usePopper = usePopper(),
      clipping = _usePopper.clipping;

  var offsetX = (clipping.right || clipping.left) && "calc(".concat(document.dir === 'ltr' ? '-50' : '50', "% - ").concat(clipping.right || clipping.left, "px)");
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Arrow,
    style: _objectSpread({}, offsetX && {
      transform: "translateX(".concat(offsetX, ")"),
      MozTransform: "translateX(".concat(offsetX, ")"),
      webkitTransform: "translateX(".concat(offsetX, ")")
    })
  });
}