"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Option = Option;
exports.OptionPrimaryContent = OptionPrimaryContent;
exports.OptionSecondaryContent = OptionSecondaryContent;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Bookend = require("../../../Bookend");

var _VisuallyHidden = require("../../../VisuallyHidden");

var _Text = require("../../../Text");

var _Radio = require("../../../Radio");

var _Checkbox = require("../../../Checkbox");

var _Theme = require("../../../Theme");

var _hooks = require("../../hooks");

var _OptionList = _interopRequireDefault(require("../../OptionList.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Option({
  id,
  label,
  details,
  children
}) {
  const {
    id: optionListId,
    selectedItems,
    allowMultiple,
    onChange
  } = (0, _hooks.useOptionList)();
  const Control = allowMultiple ? _Checkbox.CheckboxControl : _Radio.RadioControl;
  const checked = selectedItems.includes(id);
  const {
    optionList: {
      gap = 'none'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_OptionList.default.Option, gap !== 'none' && _OptionList.default.isContainer);

  function getNewSelections() {
    if (!allowMultiple) {
      return [id];
    }

    if (checked) {
      return selectedItems.filter(selectedItem => selectedItem !== id);
    }

    return [...selectedItems, id];
  }

  return /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: `${optionListId}-${id}`,
    className: _OptionList.default.OptionLabel
  }, /*#__PURE__*/_react.default.createElement(_Bookend.Bookend, {
    leading: true
  }, /*#__PURE__*/_react.default.createElement(Control, {
    id: `${optionListId}-${id}`,
    name: `${optionListId}`,
    checked: checked,
    onChange: () => onChange(getNewSelections())
  }), label && children ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, label), /*#__PURE__*/_react.default.createElement("div", {
    "aria-hidden": "true"
  }, /*#__PURE__*/_react.default.createElement(_Bookend.Bookend, {
    trailing: true
  }, children))) : /*#__PURE__*/_react.default.createElement(_Text.Text, {
    emphasized: true
  }, label))), details);
}

function OptionPrimaryContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _OptionList.default.PrimaryContent
  }, children);
}

function OptionSecondaryContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _OptionList.default.SecondaryContent
  }, children);
}