"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _TextBlock = require("../../../TextBlock");

var _Stepper = require("../../Stepper");

var _VisuallyHidden = require("../../../VisuallyHidden");

var _StepperStep = require("./StepperStep");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = id => ({
  id: `step${id}`,
  icon: 'checkmark',
  label: `Step ${id}`,
  state: `State ${id}`
});

describe('<StepperStep />', () => {
  it('renders a <StepperStepConnector /> except for first StepperStep', () => {
    const stepper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Stepper.Stepper, {
      activeStep: "step3"
    }, /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(2)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(3))));
    const [firstStepperStep, secondStepperStep, finalStepperStep] = stepper.findAll(_StepperStep.StepperStep);
    expect(firstStepperStep).not.toContainReactComponent(_StepperStep.StepperStepConnector);
    expect(secondStepperStep).toContainReactComponent(_StepperStep.StepperStepConnector, {
      active: false,
      completed: true
    });
    expect(finalStepperStep).toContainReactComponent(_StepperStep.StepperStepConnector, {
      active: true,
      completed: false
    });
  });
  it('renders <StepperStepIcon />', () => {
    const stepper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Stepper.Stepper, {
      activeStep: "step2"
    }, /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(2)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, Object.assign({}, defaultProps(3), {
      iconColor: "critical"
    }))));
    const [firstStepperStep, secondStepperStep, finalStepperStep] = stepper.findAll(_StepperStep.StepperStep);
    expect(firstStepperStep).toContainReactComponent(_StepperStep.StepperStepIcon, {
      active: false,
      completed: true,
      source: 'checkmark'
    });
    expect(secondStepperStep).toContainReactComponent(_StepperStep.StepperStepIcon, {
      active: true,
      completed: false,
      source: 'checkmark'
    });
    expect(finalStepperStep).toContainReactComponent(_StepperStep.StepperStepIcon, {
      active: false,
      completed: false,
      source: 'checkmark',
      color: 'critical'
    });
  });
  it('renders <StepperStepLabel /> with state', () => {
    const stepper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Stepper.Stepper, null, /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, Object.assign({}, defaultProps(2), {
      stateHidden: false
    }))));
    const [firstStepperStep, finalStepperStep] = stepper.findAll(_StepperStep.StepperStep);
    expect(firstStepperStep).toContainReactComponent(_StepperStep.StepperStepLabel, {
      state: 'State 1'
    });
    expect(finalStepperStep).toContainReactComponent(_StepperStep.StepperStepLabel, {
      state: 'State 2'
    });
    expect(firstStepperStep).toContainReactComponent(_VisuallyHidden.VisuallyHidden);
    expect(firstStepperStep).toContainReactComponentTimes(_TextBlock.TextBlock, 1);
    expect(finalStepperStep).not.toContainReactComponent(_VisuallyHidden.VisuallyHidden);
    expect(finalStepperStep).toContainReactComponentTimes(_TextBlock.TextBlock, 2);
    expect(firstStepperStep.find(_VisuallyHidden.VisuallyHidden)).toContainReactText('State 1');
    expect(finalStepperStep.find(_TextBlock.TextBlock)).toContainReactText('State 2');
  });
  it('renders <StepperStepLabel /> with label or description', () => {
    const stepper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Stepper.Stepper, {
      activeStep: "step2"
    }, /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, Object.assign({}, defaultProps(1), {
      description: "Description 1"
    })), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, Object.assign({}, defaultProps(2), {
      description: "Description 2"
    })), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(3))));
    const [firstStepperStep, secondStepperStep, finalStepperStep] = stepper.findAll(_StepperStep.StepperStep);
    expect(firstStepperStep).toContainReactComponent(_StepperStep.StepperStepLabel, {
      label: 'Step 1',
      description: 'Description 1'
    });
    expect(secondStepperStep).toContainReactComponent(_StepperStep.StepperStepLabel, {
      label: 'Step 2',
      description: 'Description 2'
    });
    expect(finalStepperStep).toContainReactComponent(_StepperStep.StepperStepLabel, {
      label: 'Step 3'
    });
    expect(firstStepperStep.find(_TextBlock.TextBlock)).toContainReactText('Step 1');
    expect(secondStepperStep.find(_TextBlock.TextBlock)).toContainReactText('Step 2');
    expect(finalStepperStep.find(_TextBlock.TextBlock)).toContainReactText('Step 3');
    expect(firstStepperStep).toContainReactComponentTimes(_TextBlock.TextBlock, 2);
    expect(secondStepperStep).toContainReactComponentTimes(_TextBlock.TextBlock, 2);
    expect(finalStepperStep).toContainReactComponentTimes(_TextBlock.TextBlock, 1);
  });
  it('renders a <li> with a aria-current attribute', () => {
    const stepper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Stepper.Stepper, {
      activeStep: "step2"
    }, /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(2)), /*#__PURE__*/_react.default.createElement(_StepperStep.StepperStep, defaultProps(3))));
    const [firstStepperStep, secondStepperStep, finalStepperStep] = stepper.findAll(_StepperStep.StepperStep);
    expect(firstStepperStep).toContainReactComponent('li', {
      'aria-current': false
    });
    expect(secondStepperStep).toContainReactComponent('li', {
      'aria-current': true
    });
    expect(finalStepperStep).toContainReactComponent('li', {
      'aria-current': false
    });
  });
});