"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const faker_1 = __importDefault(require("faker"));
const test_utilities_1 = require("../../../../test-utilities");
const UnstyledLink_1 = require("./UnstyledLink");
const defaultProps = {
    to: faker_1.default.internet.url(),
};
describe('<UnstyledLink />', () => {
    it('renders an anchor with expected target and rel if external', () => {
        const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps} external/>);
        expect(unstyledLink).toContainReactComponent('a', {
            target: '_blank',
            rel: 'noopener noreferrer',
        });
    });
    it('renders an anchor without target or rel if not external', () => {
        const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>);
        expect(unstyledLink).toContainReactComponent('a', {
            target: undefined,
            rel: undefined,
        });
    });
    it('renders a custom link provided by the consumer', () => {
        function CustomLink() {
            return <div>No navigation allowed!</div>;
        }
        const unstyledLink = test_utilities_1.mountWithContext(<UnstyledLink_1.UnstyledLink {...defaultProps}/>, {
            linkComponent: CustomLink,
        });
        expect(unstyledLink).toContainReactComponent(CustomLink, defaultProps);
    });
});
