"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Modal = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Portal_1 = require("../Portal");
const Heading_1 = require("../Heading");
const Icon_1 = require("../Icon");
const transition_1 = require("../../utilities/transition");
const Modal_css_1 = __importDefault(require("./Modal.css"));
const IFRAME_LOADING_HEIGHT = 200;
const DEFAULT_IFRAME_CONTENT_HEIGHT = 400;
function isIFrameProps(props) {
    return props.src !== undefined;
}
function Modal(_a) {
    var _b, _c;
    var { open: openProp = false, title, height, onClose } = _a, props = __rest(_a, ["open", "title", "height", "onClose"]);
    const iFrameTitle = 'body markup';
    const [open, setOpen] = react_1.useState(openProp);
    const [iframeHeight, setIframeHeight] = react_1.useState(IFRAME_LOADING_HEIGHT);
    const titleBarRef = react_1.useRef(null);
    const transition = transition_1.useTransition(open, { enter: 'fast' });
    const transitionClassName = Modal_css_1.default[css_utilities_1.variationName('transition', transition)];
    const closeModal = react_1.useCallback(() => {
        setOpen(false);
        if (onClose)
            onClose();
    }, [onClose]);
    const handleKeyDown = react_1.useCallback((event) => event.key === 'Escape' && closeModal(), [closeModal]);
    react_1.useEffect(() => {
        if (openProp) {
            setOpen(true);
        }
        else {
            closeModal();
        }
    }, [openProp, closeModal]);
    react_1.useEffect(() => {
        document.addEventListener('keydown', handleKeyDown, false);
        return () => {
            document.removeEventListener('keydown', handleKeyDown, false);
        };
    }, [handleKeyDown]);
    const handleIFrameLoad = react_1.useCallback((evt) => {
        const iframe = evt.target;
        if (iframe && iframe.contentWindow) {
            try {
                setIframeHeight(iframe.contentWindow.document.body.scrollHeight);
            }
            catch (_a) {
                setIframeHeight(DEFAULT_IFRAME_CONTENT_HEIGHT);
            }
        }
    }, []);
    if (!open)
        return null;
    // TODO handle focus
    let contentHeight;
    if (height) {
        if (title) {
            contentHeight = `${height - ((_c = (_b = titleBarRef.current) === null || _b === void 0 ? void 0 : _b.clientHeight) !== null && _c !== void 0 ? _c : 64)}px`;
        }
        contentHeight = `${height}px`;
    }
    else if (isIFrameProps(props)) {
        contentHeight = `${iframeHeight}px`;
    }
    else {
        contentHeight = 'auto';
    }
    return (<Portal_1.Portal>
      <div className={Modal_css_1.default.Wrapper}>
        
        <div className={css_utilities_1.classNames(Modal_css_1.default.Backdrop, transitionClassName)}/>
        <div className={css_utilities_1.classNames(Modal_css_1.default.Content, transitionClassName)}>
          {title && (<header className={Modal_css_1.default.Header} ref={titleBarRef}>
              <Heading_1.Heading level={1}>{title}</Heading_1.Heading>
              <button type="button" className={Modal_css_1.default.Button} onClick={() => closeModal()}>
                <Icon_1.Icon source="close" size="large"/>
              </button>
            </header>)}
          {isIFrameProps(props) ? (
    // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
    <iframe src={props.src} name={props.iFrameName} onLoad={handleIFrameLoad} title={iFrameTitle} className={Modal_css_1.default.IFrame} style={{
        // stylelint-disable-next-line value-keyword-case
        height: contentHeight,
    }}/>) : (<div className={Modal_css_1.default.Body} style={{
        // stylelint-disable-next-line value-keyword-case
        height: contentHeight,
    }}>
              {props.children}
            </div>)}
        </div>
      </div>
    </Portal_1.Portal>);
}
exports.Modal = Modal;
