"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.themeWithKnobs = void 0;
const react_1 = __importDefault(require("react"));
const addon_knobs_1 = require("@storybook/addon-knobs");
const __1 = require("..");
var Group;
(function (Group) {
    Group["TextFields"] = "Text fields";
    Group["Selects"] = "Selects";
    Group["Breadcrumbs"] = "Breadcrumbs";
    Group["Actions"] = "Actions";
    Group["HeadingsLevel1"] = "Headings level 1";
    Group["HeadingsLevel2"] = "Headings level 2";
    Group["HeadingsLevel3"] = "Headings level 3";
    Group["Checkbox"] = "Checkbox";
})(Group || (Group = {}));
var Label;
(function (Label) {
    Label["Border"] = "Border";
    Label["LabelPosition"] = "Label position";
})(Label || (Label = {}));
var Action;
(function (Action) {
    Action["Display"] = "Display";
})(Action || (Action = {}));
var Breadcrumb;
(function (Breadcrumb) {
    Breadcrumb["Gap"] = "Gap";
    Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
    Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));
const SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
const BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
const LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
const ACTIONS_DISPLAY_OPTIONS = optionify(['inline', 'block']);
const BREADCRUMB_GAP_OPTIONS = optionify(['base', 'loose']);
const NUMBER_STYLE_OPTIONS = optionify([
    'none',
    'decimal',
    'decimalLeadingZero',
]);
const STYLE_OPTIONS = optionify([
    'style1',
    'style2',
    'style3',
    'style4',
    'style5',
    'style6',
    'style7',
    'style8',
    'style9',
]);
const SIZE_OPTIONS = optionify([
    'base',
    'xsmall',
    'small',
    'medium',
    'large',
    'xlarge',
    'xxlarge',
]);
const LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
const FONT_OPTIONS = optionify(['primary', 'secondary']);
const WEIGHT_OPTIONS = optionify(['base', 'bold']);
const LINE_SIZE_OPTIONS = optionify(['base', 'large']);
const KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);
function themeWithKnobs(...picks) {
    return (storyFn) => <ThemeWithKnobs pick={picks}>{storyFn()}</ThemeWithKnobs>;
}
exports.themeWithKnobs = themeWithKnobs;
function ThemeWithKnobs({ pick = [], children }) {
    let textFieldsBorder;
    let selectBorder;
    let textFieldsLabelPosition;
    let selectLabelPosition;
    let actionsDisplay;
    let breadcrumbGap;
    let chevronIconSeparator = true;
    let numberStyle;
    let breadcrumbStyle;
    let headingLevel1Style;
    let headingLevel2Style;
    let headingLevel3Style;
    let checkboxBorderRadius;
    if (pick.includes('textFields')) {
        textFieldsBorder = addon_knobs_1.select(Label.Border, BORDER_OPTIONS, textFieldsBorder, Group.TextFields);
        textFieldsLabelPosition = addon_knobs_1.select(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFieldsLabelPosition, Group.TextFields);
    }
    if (pick.includes('select')) {
        selectBorder = addon_knobs_1.select(Label.Border, BORDER_OPTIONS, selectBorder, Group.Selects);
        selectLabelPosition = addon_knobs_1.select(Label.LabelPosition, LABEL_POSITION_OPTIONS, selectLabelPosition, Group.Selects);
    }
    if (pick.includes('actions')) {
        actionsDisplay = addon_knobs_1.select(Action.Display, ACTIONS_DISPLAY_OPTIONS, actionsDisplay, Group.Actions);
    }
    if (pick.includes('buyerJourney')) {
        breadcrumbGap = addon_knobs_1.select(Breadcrumb.Gap, BREADCRUMB_GAP_OPTIONS, breadcrumbGap, Group.Breadcrumbs);
        chevronIconSeparator = addon_knobs_1.boolean(Breadcrumb.ChevronIconSeparator, chevronIconSeparator, Group.Breadcrumbs);
        numberStyle = addon_knobs_1.select(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, numberStyle, Group.Breadcrumbs);
        breadcrumbStyle = addon_knobs_1.select('Style', STYLE_OPTIONS, breadcrumbStyle, Group.Breadcrumbs);
    }
    if (pick.includes('checkbox')) {
        checkboxBorderRadius = addon_knobs_1.select('Border radius', SIMPLE_BORDER_RADIUS_OPTIONS, checkboxBorderRadius, Group.Checkbox);
    }
    if (pick.includes('headingLevel1')) {
        headingLevel1Style = addon_knobs_1.select('Style', STYLE_OPTIONS, headingLevel1Style, Group.HeadingsLevel1);
    }
    if (pick.includes('headingLevel2')) {
        headingLevel2Style = addon_knobs_1.select('Style', STYLE_OPTIONS, headingLevel2Style, Group.HeadingsLevel2);
    }
    if (pick.includes('headingLevel3')) {
        headingLevel3Style = addon_knobs_1.select('Style', STYLE_OPTIONS, headingLevel3Style, Group.HeadingsLevel3);
    }
    const typographyStyles = [...Array(9)].reduce((acc, _, index) => {
        const oneBasedIndex = index + 1;
        return Object.assign(Object.assign({}, acc), { [`typographyStyle${oneBasedIndex}`]: {
                size: addon_knobs_1.select(`Style ${oneBasedIndex} size`, SIZE_OPTIONS, undefined, 'Styles'),
                letterCase: addon_knobs_1.select(`Style ${oneBasedIndex} letter case`, LETTER_CASE_OPTIONS, undefined, 'Styles'),
                fonts: addon_knobs_1.select(`Style ${oneBasedIndex} fonts`, FONT_OPTIONS, undefined, 'Styles'),
                weight: addon_knobs_1.select(`Style ${oneBasedIndex} weight`, WEIGHT_OPTIONS, undefined, 'Styles'),
                lineSize: addon_knobs_1.select(`Style ${oneBasedIndex} line size`, LINE_SIZE_OPTIONS, undefined, 'Styles'),
                kerning: addon_knobs_1.select(`Style ${oneBasedIndex} kerning`, KERNING_OPTIONS, undefined, 'Styles'),
            } });
    }, {});
    const theme = __1.createTheme(Object.assign(Object.assign({ textFields: {
            border: textFieldsBorder,
            labelPosition: textFieldsLabelPosition,
        }, select: { border: selectBorder, labelPosition: selectLabelPosition }, actions: { display: actionsDisplay }, buyerJourney: {
            gap: breadcrumbGap,
            chevronIconSeparator,
            numberStyle,
            typographyStyle: breadcrumbStyle,
        }, headingLevel1: { typographyStyle: headingLevel1Style }, headingLevel2: { typographyStyle: headingLevel2Style }, headingLevel3: { typographyStyle: headingLevel3Style } }, typographyStyles), { checkbox: { borderRadius: checkboxBorderRadius } }));
    return <__1.Theme theme={theme}>{children}</__1.Theme>;
}
function optionify(array) {
    return array.reduce((acc, value) => (Object.assign(Object.assign({}, acc), { [value]: value })), {
        ' ': undefined,
    });
}
